import { FrontOfficeTicketData } from "./frontOfficeTicketData";
import { FrontOfficeExecuteActionDataAction } from "./frontOfficeExecuteActionData";
export declare class FrontOfficeClient {
    private readonly connector;
    private readonly approvalProcessEndpoint;
    private readonly ticketsEndpoint;
    private readonly maxResponseLength;
    constructor(connector: string);
    /**
     * Creates JSON object with mandatory parameters representing body that can be send as POST to /tickets endpoint.
     * @return JSON object
     */
    getSingleTicketData(stateId: string, holderType: string, holderValue: string, template: string, attachmentFromGlobalStorageEnabled?: boolean, uploadAttachmentFromLocalDriveEnabled?: boolean): FrontOfficeTicketData;
    /**
     * Creates Front Office ticket.
     * @param data JSON object that will be given as body
     * @returns Promise of ID of created ticket.
     */
    createSingleTicket(data: FrontOfficeTicketData): Promise<string>;
    /**
     * Creates approval process action.
     * @actionId The approval-process action's ID as defined in the approval process.
     * @guid The ticket's GUID.
     * @message Custom message about the approval-process action.
     * @return JSON object
     */
    getApprovalProcessesExecuteActionData(actionId: string, guid: string, message: string): FrontOfficeExecuteActionDataAction;
    /**
     * Executes approval process actions.
     * @frontOfficeExecuteActionDataActions The approval process action that moves the ticket to the desired state.
     */
    approvalProcessesExecuteActions(frontOfficeExecuteActionDataActions: FrontOfficeExecuteActionDataAction[]): Promise<void>;
    private fetchApprovalProcessesExecuteAction;
    private fetchFrontOffice;
    private getWaitingTime;
    private wait;
}
